
# EXAMPLE OF ROUTINES USED AFTER INITIAL HOMOLOGY MODELLEING

# Import the Modeller module
from modeller import *

env = environ()
env.io.atom_files_directory = ['.']
env.io.hetatm = False
env.io.water = False

env.libs.topology.read(file='$(LIB)/top_heav.lib') # read topology
env.libs.parameters.read(file='$(LIB)/par.lib') # read parameters

code = 'model1'

from modeller.scripts import complete_pdb
mdl = complete_pdb(env,code)

mdl.write(file=code+'.ini')

def select_hot():
	atmsel = selection(mdl)
	atmsel.energy()
	mdl.restraints.make(atmsel, restraint_type='stereo', spline_on_site=False)
	mdl.restraints.write(file=code+'.rsr')
	atmsel = atmsel.hot_atoms(pick_hot_cutoff=4.0).by_residue()
	#for k in range(1040,1062): atmsel.add(mdl.residues['%d:A'%(k)])
	#for k in range(3283,3303): atmsel.add(mdl.residues['%d:C'%(k)])
	mdl.restraints.unpick_all()
	mdl.restraints.pick(atmsel)
	return atmsel

from modeller.optimizers import conjugate_gradients,molecular_dynamics,actions
md = molecular_dynamics (output='REPORT')
cg = conjugate_gradients(output='REPORT')
with open(code+'.CG.dat', 'w') as logfile:
	atmsel = select_hot()
	cg.optimize(atmsel, max_iterations = 1500, actions = actions.trace(5,open(code+'.CG.dat', 'w')))
	atmsel = select_hot()
	md.optimize(atmsel, max_iterations = 500, actions = actions.trace(5,open(code+'.MD.dat', 'w')))
	#atmsel = select_hot()
	#cg.optimize(atmsel, max_iterations = 10000,actions = actions.trace(5,open(code+'.CG.dat', 'a')))


atmsel.energy()

mdl.write(file=code+'_min.pdb',model_format='PDB')


